.. _gemini_principles:

=================
Gemini Principles
=================

The Gemini Principles have been derived by the `Centre for Digital Built Britain (CDBB) <https://www.cdbb.cam.ac.uk/system/files/documents/TheGeminiPrinciples.pdf>`_.

We strongly recommend you give them a read if embarking on a digital twins project.

The aim of **twined** is to enable the following principles in particular:

#. Openness (using an open-source project to create schema for applications/twins that can be run anywhere, anywhen)
#. Federation (encouraging a standardised way of connecting twins together)
#. Security (making sure schemas and data can be read safely)
#. Public Good (see our nano-rant about climate change in :ref:`reason_for_being`)
